@@ -15,7 +15,7 @@ from xgboost import XGBClassifier
 
 from . import mokapot
 from .mokapot.parsers.fasta import _parse_protein, _parse_fasta_files, read_fasta
-from .parsing import convert_to_csv, convert_to_moka, get_filter_results_moka, align_mass, parse_dta_args
+from .parsing import convert_sqt_to_df, convert_to_moka, get_filter_results_moka, align_mass, parse_dta_args
 from .util import xml_to_dict
 from .config import *
 
@@ -147,7 +147,14 @@ def run():
                                                             args.filter_level)
 
     with open(Path(args.out), 'w') as file:
-        file.write(dta_filter_content.read())
+        for i, line in enumerate(dta_filter_content):
+            if i == 1:
+                for fasta_path in fasta_paths:
+                    file.write(str(fasta_path) + '\n')
+                for sqt_path in sqt_paths:
+                    file.write(str(sqt_path.parent) + '\n')
+            file.write(line)
+        #file.write(dta_filter_content.read())
 
     pin_df.to_csv(args.out + '.pin', index=False)
 
@@ -166,6 +173,58 @@ def run():
         search_xml.close()
 
 
+def create_hline(timscore, tabulated_args):
+    if timscore is True:
+        return ['DTASelect v2.1.13\n',
+                   tabulated_args,
+                   '\n',
+                   'Locus	Sequence Count	Spectrum Count	Sequence Coverage	Length	MolWt	pI	'
+                   'Validation Status	NSAF	EMPAI	Descriptive Name	HRedundancy	LRedundancy	MRedundancy\n',
+                   'Unique	FileName	XCorr	DeltCN	Conf%	M+H+	CalcM+H+	PPM	TotalIntensity	SpR	'
+                   'Prob Score	pI	IonProportion	Redundancy	Measured_IM_Value	Predicted_IM_Value	IM_Score	'
+                   'Sequence	ExperimentalMz	Corrected1k0	IonMobility	RetTime	PTMIndex	PTMIndex Protein List\n'
+                   ]
+    else:
+        return ['DTASelect v2.1.12\n',
+                   tabulated_args,
+                   '\n',
+                   'Locus	Sequence Count	Spectrum Count	Sequence Coverage	Length	MolWt	pI	Validation Status	'
+                   'NSAF	EMPAI	Descriptive Name	HRedundancy	LRedundancy	MRedundancy\n',
+                   'Unique	FileName	XCorr	DeltCN	Conf%	M+H+	CalcM+H+	PPM	TotalIntensity	SpR	Prob Score	'
+                   'pI	IonProportion	Redundancy	Sequence	RetTime	PTMIndex	PTMIndex Protein List\n'
+                   ]
+
+
+def create_empty_filter(timscore, tabulated_args):
+    h_lines = create_hline(timscore, tabulated_args)
+
+    end_lines = [f'\tProteins\tPeptide IDs\tSpectra\n',
+                 f'Unfiltered\t{0}\t{0}\t{0}\n',
+                 f'Filtered\t{0}\t{0}\t{0}\n',
+                 f'Forward\t{0}\t{0}\t{0}\n',
+                 f'Redundant Forward matches\t{0}\t{0}\t{0}\n',
+                 f'Decoy matches\t{0}\t{0}\t{0}\n',
+                 f'Redundant Decoy matches\t{0}\t{0}\t{0}\n',
+                 f'Forward FDR\t{0}\t{0}\t{0}\n',
+                 f'\n',
+                 f'Classification\tNonredundant Proteins\tRedundant Proteins\n',
+                 f'Unclassified\t{0}\t{0}']
+
+    if timscore is True:
+        return dtaselectfilter.to_dta_select_filter(
+            version=dtaselectfilter.DtaSelectFilterVersion.V2_1_13_timscore,
+            h_lines=h_lines,
+            dta_filter_results=[],
+            end_lines=end_lines)
+    else:
+        return dtaselectfilter.to_dta_select_filter(
+            version=dtaselectfilter.DtaSelectFilterVersion.V2_1_12_paser,
+            h_lines=h_lines,
+            dta_filter_results=[],
+            end_lines=end_lines)
+
+
+
 def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
                fastas: Tuple[Iterator[IO[str]], List[str]],
                protein_fdr: float,
@@ -200,7 +259,8 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
     :return: str - the string contents of the output DTASelect-filter.txt file
     """
 
-    if dta_params: # parse DTASelect.params files
+    # parse DTASelect.params file and override default arguments
+    if dta_params:
         dta_args = parse_dta_args(dta_params.read().rstrip())
         fp_fdr = float(dta_args.get('--fp', 1.0))
         pfp_fdr = float(dta_args.get('--pfp', 1.0))
@@ -211,7 +271,8 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
         timscore = dta_args.get('--timscore', timscore)
         filter_level = int(dta_args.get('-t', filter_level))
 
-    if search_xml: # search.xml file
+    # parse search.xml file and override default arguments
+    if search_xml:
         xml_dict = xml_to_dict(search_xml)
         missed_cleavage = int(xml_dict['enzyme_info']['max_num_internal_mis_cleavage'])
         if missed_cleavage == -1:
@@ -256,7 +317,6 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
         ['xcorr_filter', xcorr_filter],
         ['filter_level', filter_level]
     ], headers=['Argument', 'Value'], missingval='None')
-
     logging.info(tabulated_args)
 
     # Set the random seed:
@@ -264,7 +324,7 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
         logging.info(f'Setting random seed: {seed}')
         np.random.seed(seed)
 
-    sqt_dfs = [convert_to_csv(sqt_io, sqt_stem, xcorr_filter, max_mline) for sqt_io, sqt_stem in zip(sqts[0], sqts[1])]
+    sqt_dfs = [convert_sqt_to_df(sqt_io, sqt_stem, xcorr_filter, max_mline) for sqt_io, sqt_stem in zip(sqts[0], sqts[1])]
 
     alignment_figs = []
     if mass_alignment is True:
@@ -313,14 +373,16 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
                                        test_fdr=test_fdr,
                                        folds=folds,
                                        max_workers=workers)
+
+    # Return empty DTASelect-filter.txt file if there are an insufficient number of PSMs
     except RuntimeError as err:
-        logging.error(f'Runtime Error: {err} Likely too few PSMs...')
+        logging.error(f'RuntimeError: {err} Likely too few PSMs...')
         logging.info('Writing alignment figures, pin_df and empty DTASelect-filter.txt file.')
-        return alignment_figs, pin_df, StringIO(EMPTY_DTA_FILTER)
+        return alignment_figs, pin_df, StringIO(create_empty_filter(timscore, tabulated_args))
     except ValueError as err:
         logging.error(f'ValueError: {err} Likely too few PSMs...')
         logging.info('Writing alignment figures, pin_df and empty DTASelect-filter.txt file.')
-        return alignment_figs, pin_df, StringIO(EMPTY_DTA_FILTER)
+        return alignment_figs, pin_df, StringIO(create_empty_filter(timscore, tabulated_args))
 
     # separate protein, peptide, and psm dataframes
     target_psm_results, target_peptide_results, target_protein_results = results.confidence_estimates['psms'], \
@@ -436,6 +498,8 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
     if (decoy_spectra + target_spectra) != 0:
         spectra_fdr = round(decoy_spectra / (decoy_spectra + target_spectra) * 100, 4)
 
+    h_lines = create_hline(timscore, tabulated_args)
+
     end_lines = [f'\tProteins\tPeptide IDs\tSpectra\n',
                  f'Unfiltered\t{unfiltered_proteins}\t{unfiltered_peptides}\t{unfiltered_psms}\n',
                  f'Filtered\t{decoy_protein_groups + target_protein_groups}\t{target_peptides + decoy_peptides}\t{target_spectra + decoy_spectra}\n',
@@ -449,29 +513,12 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
                  f'Unclassified\t{decoy_protein_groups + target_protein_groups}\t{(target_proteins + decoy_proteins) - (decoy_protein_groups + target_protein_groups)}']
 
     if timscore is True:
-        h_lines = ['DTASelect v2.1.13\n',
-                   tabulated_args,
-                   '\n',
-                   'Locus	Sequence Count	Spectrum Count	Sequence Coverage	Length	MolWt	pI	'
-                   'Validation Status	NSAF	EMPAI	Descriptive Name	HRedundancy	LRedundancy	MRedundancy\n',
-                   'Unique	FileName	XCorr	DeltCN	Conf%	M+H+	CalcM+H+	PPM	TotalIntensity	SpR	'
-                   'Prob Score	pI	IonProportion	Redundancy	Measured_IM_Value	Predicted_IM_Value	IM_Score	'
-                   'Sequence	ExperimentalMz	Corrected1k0	IonMobility	RetTime	PTMIndex	PTMIndex Protein List\n'
-                   ]
         dta_filter_content = dtaselectfilter.to_dta_select_filter(
             version=dtaselectfilter.DtaSelectFilterVersion.V2_1_13_timscore,
             h_lines=h_lines,
             dta_filter_results=filter_results,
             end_lines=end_lines)
     else:
-        h_lines = ['DTASelect v2.1.12\n',
-                   tabulated_args,
-                   '\n',
-                   'Locus	Sequence Count	Spectrum Count	Sequence Coverage	Length	MolWt	pI	Validation Status	'
-                   'NSAF	EMPAI	Descriptive Name	HRedundancy	LRedundancy	MRedundancy\n',
-                   'Unique	FileName	XCorr	DeltCN	Conf%	M+H+	CalcM+H+	PPM	TotalIntensity	SpR	Prob Score	'
-                   'pI	IonProportion	Redundancy	Sequence	RetTime	PTMIndex	PTMIndex Protein List\n'
-                   ]
         dta_filter_content = dtaselectfilter.to_dta_select_filter(
             version=dtaselectfilter.DtaSelectFilterVersion.V2_1_12_paser,
             h_lines=h_lines,
