@@ -28,7 +28,7 @@ def parse_dta_args(arg_string):
     return arg_dict
 
 
-def convert_to_csv(sqt_content: TextIOWrapper | StringIO, filename=None, xcorr_filter=None, max_mline=None) -> pd.DataFrame:
+def convert_sqt_to_df(sqt_content: TextIOWrapper | StringIO, filename=None, xcorr_filter=None, max_mline=None) -> pd.DataFrame:
     """
     Convert SQT filee into a pandas df
     :param max_mline:
